@@ -15,9 +15,9 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.cl_template import TemplateFormat
+from ..cl_template import TemplateFormat
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
